==> deepin-camera_6.0.11.tar.xz: BUILD/src/translations/deepin-camera_hi_IN.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hi_IN">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>वीडियो रिकॉर्ड प्रक्रिया जारी है। विंडो बंद की जाएँ?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>फोटो</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>कैमरा बदलें</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>बंद करें</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिंट करें</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>आपके पास इस फोल्डर के उपयोग हेतु अनुमति नहीं है</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">अमान्य फोल्डर</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>फाइल स्थान</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>रिकॉर्डिंग आरंभ</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>निरंतर फोटो मोड</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>फोटो टाइमर विलंब</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>आउटपुट</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>आउटपुट प्रारूप</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 पीसीएस</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 पीसीएस</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>कैमरा</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>कैमरा - कंप्यूटर कैमरा या वेब कैम उपयोग कर चित्र लेने व वीडियो हेतु साधन है।</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>फाइल संचित नहीं हुई</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">यहाँ संचित करें :</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>फोटो :</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>वीडियो :</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>रेजोलुशन सेटिंग्स</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">रेजोलुशन :</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>फोटो :</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>वीडियो :</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ध्वनि प्रभाव</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>दर्पण मोड</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>फ्लैश लाइट</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>कैमरा</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>रिकॉर्डिंग बंद करें</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिंट करें</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट दिखाएँ</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>चित्र लेना बंद करें</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>संदर्भ मेन्यू</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">चित्र लें</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">वीडियो रिकॉर्ड करें</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">चित्र लेना बंद करें</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>फ्लैश लाइट</translation>
    </message>
    <message>
        <source>On</source>
        <translation>चालू</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>बंद</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>चित्र लेने में विलंब</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>कोई वेब कैम नहीं मिला</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>वेब कैम कार्यरत है</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">रिकॉर्डिंग बंद करें</translation>
    </message>
</context>
</TS>

==> deepin-camera_6.5.20.tar.xz: BUILD/src/translations/deepin-camera_hi_IN.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="hi_IN">
<context>
    <name>CMainWindow</name>
    <message>
        <source>Video recording is in progress. Close the window?</source>
        <translation>वीडियो रिकॉर्ड प्रक्रिया जारी है। विंडो बंद की जाएँ?</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation type="vanished">फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Photo</source>
        <translation>फोटो</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>वीडियो</translation>
    </message>
    <message>
        <source>Switch Cameras</source>
        <translation>कैमरा बदलें</translation>
    </message>
</context>
<context>
    <name>CloseDialog</name>
    <message>
        <source>Cancel</source>
        <translation>रद्द करें</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>बंद करें</translation>
    </message>
</context>
<context>
    <name>ImageItem</name>
    <message>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिंट करें</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>You don&apos;t have permission to operate this folder</source>
        <translation>आपके पास इस फोल्डर के उपयोग हेतु अनुमति नहीं है</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>बंद करें</translation>
    </message>
    <message>
        <source>Invalid folder</source>
        <translation type="vanished">अमान्य फोल्डर</translation>
    </message>
    <message>
        <source>Open folder</source>
        <translation>फोल्डर खोलें</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>सामान्य</translation>
    </message>
    <message>
        <source>File location</source>
        <translation>फाइल स्थान</translation>
    </message>
    <message>
        <source>Shoot</source>
        <translation>रिकॉर्डिंग आरंभ</translation>
    </message>
    <message>
        <source>Burst mode</source>
        <translation>निरंतर फोटो मोड</translation>
    </message>
    <message>
        <source>Self-timer delay</source>
        <translation>फोटो टाइमर विलंब</translation>
    </message>
    <message>
        <source>Output</source>
        <translation>आउटपुट</translation>
    </message>
    <message>
        <source>Output format</source>
        <translation>आउटपुट प्रारूप</translation>
    </message>
    <message>
        <source>4 pcs</source>
        <translation>4 पीसीएस</translation>
    </message>
    <message>
        <source>10 pcs</source>
        <translation>10 पीसीएस</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Camera</source>
        <translation>कैमरा</translation>
    </message>
    <message>
        <source>Camera is an image and video capture utility using your PC camera or webcam.</source>
        <translation>कैमरा - कंप्यूटर कैमरा या वेब कैम उपयोग कर चित्र लेने व वीडियो हेतु साधन है।</translation>
    </message>
    <message>
        <source>File not saved</source>
        <translation>फाइल संचित नहीं हुई</translation>
    </message>
    <message>
        <source>Save to:</source>
        <translation type="vanished">यहाँ संचित करें :</translation>
    </message>
    <message>
        <source>Photo:</source>
        <translation>फोटो :</translation>
    </message>
    <message>
        <source>Video:</source>
        <translation>वीडियो :</translation>
    </message>
    <message>
        <source>Resolution settings</source>
        <translation>रेजोलुशन सेटिंग्स</translation>
    </message>
    <message>
        <source>Resolution:</source>
        <translation type="vanished">रेजोलुशन :</translation>
    </message>
    <message>
        <source>Photos:</source>
        <translation>फोटो :</translation>
    </message>
    <message>
        <source>Videos:</source>
        <translation>वीडियो :</translation>
    </message>
    <message>
        <source>Sound effects</source>
        <translation>ध्वनि प्रभाव</translation>
    </message>
    <message>
        <source>Mirror mode</source>
        <translation>दर्पण मोड</translation>
    </message>
    <message>
        <source>Flashlight</source>
        <translation>फ्लैश लाइट</translation>
    </message>
    <message>
        <source>Gridlines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>1*1 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>2*2 lines</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Maximum resolution:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Camera</source>
        <translation>कैमरा</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>सेटिंग्स</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation>रिकॉर्डिंग बंद करें</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>कॉपी करें</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>हटाएँ</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>खोलें</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>प्रिंट करें</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>सहायता</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>शॉर्टकट दिखाएँ</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation>चित्र लेना बंद करें</translation>
    </message>
    <message>
        <source>Context menu</source>
        <translation>संदर्भ मेन्यू</translation>
    </message>
</context>
<context>
    <name>ThumbnailsBar</name>
    <message>
        <source>Take photo</source>
        <translation type="vanished">चित्र लें</translation>
    </message>
    <message>
        <source>Record video</source>
        <translation type="vanished">वीडियो रिकॉर्ड करें</translation>
    </message>
    <message>
        <source>Stop taking photos</source>
        <translation type="vanished">चित्र लेना बंद करें</translation>
    </message>
</context>
<context>
    <name>dc::Settings</name>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
</context>
<context>
    <name>filterPreviewButton</name>
    <message>
        <source>Normal</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Vivid</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Warm</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Cold</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Retro</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Film</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Gray</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>B&amp;W</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>takePhotoSettingAreaWidget</name>
    <message>
        <source>Flashlight</source>
        <translation>फ्लैश लाइट</translation>
    </message>
    <message>
        <source>On</source>
        <translation>चालू</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>बंद</translation>
    </message>
    <message>
        <source>Delay capture</source>
        <translation>चित्र लेने में विलंब</translation>
    </message>
    <message>
        <source>None</source>
        <translation>कुछ नहीं</translation>
    </message>
    <message>
        <source>Filters</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Exposure</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>videowidget</name>
    <message>
        <source>No webcam found</source>
        <translation>कोई वेब कैम नहीं मिला</translation>
    </message>
    <message>
        <source>The webcam is in use</source>
        <translation>वेब कैम कार्यरत है</translation>
    </message>
    <message>
        <source>Stop recording</source>
        <translation type="vanished">रिकॉर्डिंग बंद करें</translation>
    </message>
</context>
</TS>
